@@ -3,8 +3,8 @@ context("EQ-5D-DS")
 test1.df <- data.frame(MO=c(1,2,3,2,1,2), SC=c(2,3,2,1,2,3), UA=c(3,2,1,2,3,1), PD=c(1,1,2,3,2,1), AD=c(2,2,3,3,1,1), Sex=c("M","F","M","F","M","F"))
 test2.df <- data.frame(MO=c(1,2,3,NA,1,2), SC=c(2,3,2,1,2,3), UA=c("F",2,1,2,3,1), PD=c(1,1,2,3,2,1), AD=c(2,2,3,3,1,1), Sex=c("M","F","M","F","M","F"))
 test3.df <- data.frame(Mob=c(1,2,3,2,1,2), SCa=c(2,3,2,1,2,3), UAc=c(3,2,1,2,3,1), PaD=c(1,1,2,3,2,1), AaD=c(2,2,3,3,1,1), Sex=c("M","F","M","F","M","F"))
-test4.df <- data.frame(State=eq5d::getHealthStatesFromDimensions(test1.df), Sex=test1.df$Sex)
-test5.df <- data.frame(Profile=eq5d::getHealthStatesFromDimensions(test1.df), Sex=test1.df$Sex)
+test4.df <- data.frame(State=eq5d::get_health_states_from_dimensions(test1.df), Sex=test1.df$Sex)
+test5.df <- data.frame(Profile=eq5d::get_health_states_from_dimensions(test1.df), Sex=test1.df$Sex)
   
 res1.df <- data.frame(MO=c(33.3,50.0,16.7),SC=c(16.7,50.0,33.3),UA=c(33.3,33.3,33.3),PD=c(50.0,33.3,16.7),AD=c(33.3,33.3,33.3))
 res2.df <- data.frame(MO=c(2,3,1),SC=c(1,3,2),UA=c(2,2,2),PD=c(3,2,1),AD=c(2,2,2))
